@@ -20,6 +20,14 @@
 
 
 
+prepanel.null <- function() {
+    list(xlim = rep(NA_real_, 2),
+         ylim = rep(NA_real_, 2),
+         dx = NA_real_,
+         dy = NA_real_)
+}
+
+
 
 cupdate <- function(index, maxim)
 {
@@ -430,6 +438,43 @@ banking <- function(dx, dy = 1)
 
 
 
+## method in Visualizing Data: needs x-range and y-range as well.  Not
+## sure what the best way to extend the API is; for now, we will just
+## define (but not export) an implementation
+
+
+weighted.banking <-
+    function(dx, dy = 1, xrange = sum(dx), yrange = sum(dy))
+{
+    if (is.list(dx)) {
+        if (is.null(names(dx))) names(dx) <- c("dx", "dy")
+        dy <- abs(dx[["dy"]])
+        dx <- abs(dx[["dx"]])
+    }
+    if (length(dx)!=length(dy)) stop("Non matching lengths")
+    id <- dx!=0 & dy!=0 & !is.na(dx) & !is.na(dy)
+    if (any(id))
+    {
+        ndx <- dx / xrange
+        ndy <- dy / yrange
+        obj <- function(a)
+        {
+            sum(atan(a * ndy / ndx) * sqrt(ndx^2 + a^2 * ndy^2) ) /
+                sum(sqrt(ndx^2 + a^2 * ndy^2)) -
+                    base::pi / 4 
+        }
+        ##         r  <- abs(dx[id]/dy[id])
+        ##         median(r)
+        ## transform to have arg between 0 and 1
+        objtan <- function(x) obj(tan(base::pi * x / 2))
+        u <- uniroot(f = objtan, lower = 0.01, upper = 0.99)
+        aspect.ratio <- tan(base::pi * u$root / 2)
+        aspect.ratio * xrange / yrange
+    }
+    else 1
+}
+
+
 
 
 
@@ -444,7 +489,7 @@ extend.limits <-
              else lattice.getOption("axis.padding")$numeric)
 {
     ## if (!is.numeric(lim)) NA
-    if (is.character(lim)) NA # or lim?
+    if (is.character(lim) || all(is.na(lim))) NA_real_ # or lim?
     else if (length(lim) == 2)
     {
         if (lim[1] > lim[2])
@@ -645,7 +690,7 @@ cond.orders <- function(foo, ...)
                 }
                 else  ## this happens for empty panels
                 {
-                    panel.order[count] <- NA
+                    is.na(panel.order) <- count # panel.order[count] <- NA
                 }
             }
             dim(panel.order) <- sapply(foo$condlevels, length)
@@ -684,7 +729,7 @@ compute.layout <-
             layout[1] <- cond.max.level[1]
             layout[2] <- cond.max.level[2]
         }
-        skip <- rep(skip, length = max(layout[1] * layout[2], layout[2]))
+        skip <- rep(skip, length.out = max(layout[1] * layout[2], layout[2]))
         plots.per.page <- length(skip) - length(skip[skip])
         layout[3] <- ceiling(nplots/plots.per.page) # + 1
     }
@@ -696,7 +741,7 @@ compute.layout <-
             stop("at least one element of layout must be positive")
         else if (layout[2]==0) stop("inadmissible value of layout")
         
-        skip <- rep(skip, length = max(layout[1] * layout[2], layout[2]))
+        skip <- rep(skip, length.out = max(layout[1] * layout[2], layout[2]))
         plots.per.page <- length(skip) - length(skip[skip])
         layout[3] <- ceiling(nplots / plots.per.page) # + 1 
     }
